package com.antai.sport.http.server.game.api.business.match.bicycle;

import com.antai.sport.http.server.common.annotation.LoginSportUser;
import com.antai.sport.http.server.common.base.Result;
import com.antai.sport.http.server.game.api.business.match.bicycle.dto.DtoMatchBicycleResult;
import com.antai.sport.http.server.game.api.business.match.bicycle.dto.RespMatchBicycleList;
import com.antai.sport.http.server.repository.sport.entity.SportUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

import static com.antai.sport.http.server.common.util.ResultUtil.success;

/**
 * @Author liming
 * @Date 2021/9/11 18:31
 * @Email lmmax@126.com
 * @Description:
 */
@RestController()
@RequestMapping("/match/bicycle")
@Api(tags = {"比赛相关接口"})
public class MatchBicycleController {
    @Resource
    private MatchBicycleService matchBicycleService;
    @Resource
    private MatchBicyclePlayerService matchBicyclePlayerService;

    @GetMapping()
    @ApiOperation(value = "获取比赛列表接口", notes = "data为比赛列表数据")
    public ResponseEntity<Result<List<RespMatchBicycleList>>> getMatchBicycleList() {
        return success(matchBicycleService.getMatchBicycleList());
    }

    @PostMapping("/entry/{matchId}")
    @ApiOperation(value = "加入比赛接口")
    public ResponseEntity<Result> entryMatchBicycle(@LoginSportUser SportUser loginUser, @PathVariable Long matchId) {
        matchBicycleService.entryMatchBicycle(loginUser, matchId);
        return success();
    }

    @PostMapping("/player/record")
    @ApiOperation(value = "比赛数据保存")
    public ResponseEntity<Result> saveMatchBicyclePlayerRecord(@RequestBody List<DtoMatchBicycleResult> resultList) {
        matchBicyclePlayerService.saveMatchBicyclePlayerRecord(resultList);
        return success();
    }

    @GetMapping("/player/record/{matchId}")
    @ApiOperation(value = "比赛数据查询")
    public ResponseEntity<Result<List<DtoMatchBicycleResult>>> getMatchBicyclePlayerRecord(@PathVariable Long matchId) {
        return success(matchBicyclePlayerService.getMatchBicyclePlayerRecord(matchId));
    }
}
